@@ -1,5 +1,5 @@
 /*
- *  $Id: get_model_name.c,v 1.1 2001/12/10 21:12:12 davej Exp $
+ *  $Id: get_model_name.c,v 1.4 2003/06/13 11:36:20 davej Exp $
  *  This file is part of x86info.
  *  (C) 2001 Dave Jones.
  *
@@ -12,18 +12,20 @@
 #include <stdio.h>
 #include "x86info.h"
 
-void get_model_name (unsigned long maxei, struct cpudata *cpu)
+void get_model_name (struct cpudata *cpu)
 {
 	unsigned int i, j;
 	unsigned long eax, ebx, ecx, edx;
 	char namestring[49], *cp;
 
-	if (maxei < 0x80000004)
+	if (cpu->maxei < 0x80000004)
 		return;
 
 	cp = namestring;
 	for (j = 0x80000002; j <= 0x80000004; j++) {
 		cpuid (cpu->number, j, &eax, &ebx, &ecx, &edx);
+		if (eax==0)
+			return;
 
 		for (i = 0; i < 4; i++)
 			*cp++ = eax >> (8 * i);
@@ -34,5 +36,8 @@ void get_model_name (unsigned long maxei, struct cpudata *cpu)
 		for (i = 0; i < 4; i++)
 			*cp++ = edx >> (8 * i);
 	}
-	printf ("Processor name string: %s\n\n", namestring);
+	cp = namestring;
+	while(*cp == ' ')
+		cp++;
+	printf ("Processor name string: %s\n\n", cp);
 }
